@@ -7,7 +7,7 @@ import compare_versions
 import dateutil
 import yaml
 
-__version__ = '0.3.2'
+__version__ = '0.3.3'
 version = __version__
 __edition__ = 'Community'
 edition = __edition__
@@ -80,3 +80,21 @@ class Data:
         OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
         """.format(years, company)
     ).strip()
+
+    @classmethod
+    def get_dependency(cls):
+        dependencies = dict(
+            compare_versions=dict(
+                package=cls.compare_versions_text,
+                url=cls.compare_versions_link
+            ),
+            dateutil=dict(
+                package=cls.python_dateutil_text,
+                url=cls.python_dateutil_link
+            ),
+            pyyaml=dict(
+                package=cls.pyyaml_text,
+                url=cls.pyyaml_link
+            )
+        )
+        return dependencies
